mmusicc.database package
========================

mmusicc.database.metadb module
------------------------------

.. automodule:: mmusicc.database.metadb
   :members:
   :undoc-members:
   :show-inheritance:
